#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.2.1.0
visibility:           public
id:                   aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY
key:                  aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  d61dd70cb407fe4e6e924696a89a27be
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Text
    Data.Aeson.Decoding.Tokens Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Key Data.Aeson.KeyMap
    Data.Aeson.QQ.Simple Data.Aeson.RFC8785 Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Conversion Data.Aeson.Decoding.Internal
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.ByteString
    Data.Aeson.Internal.Functions Data.Aeson.Internal.Prelude
    Data.Aeson.Internal.Scientific Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Unescape
    Data.Aeson.Internal.UnescapeFromText Data.Aeson.Internal.Word8
    Data.Aeson.Internal.Word16 Data.Aeson.Parser.Time
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-2.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-2.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-2.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY
depends:
    OneTuple-0.4.2.1-CVhl6uJy3CB8we9xlpNtsq
    QuickCheck-2.15.0.1-E7cfXUQH5j0nG0YUtYjiD base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.4-69WfQsnZHyCCW0IKJYpAgN deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    generically-0.1.1-I9byc5Nil798plofO827gA ghc-prim-0.10.0
    hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    integer-conversion-0.1.1-3KyoL4eJ0Mf1thqzW3vl0x
    integer-logarithms-1.0.4-6UL0kg8BhCJ4T8veBRUxLn
    network-uri-2.6.4.2-JVtNAVx4uuKIiYA1iZNoT1
    primitive-0.9.1.0-CTO5MxhiVrsFEEvGOrOd6k
    scientific-0.3.8.1-7BwanMPzFRn1JLyZrCxw2n
    semialign-1.3.1-ELukNnUoC7P4f0m6sXsi52
    strict-0.5.1-BC2crl8B6YFCo6l1KZoeo
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2 text-iso8601-0.1.1.1-26TIP5cJiCICTxAwllAzE4
    text-short-0.1.6.1-3nUKSmeiTfj1TMpXsexk9i
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
    these-1.2.1-B3VVTusmm6G5z27U5p7uho time-1.12.2
    time-compat-1.9.9-FYGXcmZUQDf17n8TM2dyua
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    uuid-types-1.0.6-9F2zYlgPFGM8BBcRnlsvq3
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg
    witherable-0.4.2-DirsCrmAYDDI8dRzRMo1x7

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

